%% Initilization

%       distribution    Distribution used for the GLM fit.
%                       OPTIONAL, default = 'Normal'.
%                       Possible values:
%                       'normal'	        Normal distribution
%                       'logNormal'         Normal distribution on log-values
%                       'binomial'	        Binomial distribution
%                       'poisson'	        Poisson distribution
%                       'gamma'	            Gamma distribution
%                       'inverseGaussian'	Inverse Gaussian distribution
%
%       link            Link function used for the GLM fit.
%                       OPTIONAL, default depends on chosen distribution.
%                       Possible values:
%                       'identity'	    g(mu) = mu.             Default for Normal distribution
%                       'log'	        g(mu) = log(mu).        Default for Poisson
%                       'logit'	        g(mu) = log(mu/(1-mu))  Default for Binomial distribution
%                       'loglog'	    g(mu) = log(-log(mu))
%                       'probit'	    g(mu) = norminv(mu)
%                       'comploglog'	g(mu) = log(-log(1-mu))
%                       'reciprocal'	g(mu) = mu.^(-1)        Default for Gamma
%                       Scalar p	    g(mu) = mu.^p           Default for InverseGaussian (p= -2)

%% Init

fprintf('Initializing...\n');

% clear workspace
clear
close all

% restore default path
restoredefaultpath;

% add library and subfolders to path
% addpath(genpath('../../kbstat_lnk'));
addpath(genpath('../../kbstat'));
resultsDir = '../Statistics_tmp';

%% Global options

globalOptions = struct;
globalOptions.inFile = '../Data/Data.csv';
% globalOptions.id = 'Subject';
% globalOptions.x = 'Condition, Side';
% globalOptions.within = 'Condition, Side';
% globalOptions.interact = 'Condition, Side';
globalOptions.showVarNames = 'levels';
globalOptions.posthocMethod = 'emm';
globalOptions.posthocLevel = 2;
globalOptions.levelOrder = 'stable';
globalOptions.markerSize = 2;
globalOptions.rescale = 'false';
globalOptions.outlierMethod = 'quartiles';
globalOptions.fitMethod = 'MPL';

%% Analysis of shear forces

globalOptions.y = {
    'maxFxy'
    % 'maxAbsFx'
    % 'maxAbsFy'
    };
globalOptions.yLabel = {
    'Maximum shear JCF'
    % 'Max force X'
    % 'Max force Y'
    };
globalOptions.yUnits = {
    'BW'
    };
globalOptions.distribution = {
    'gamma'
    };

% globalOptions.link = {
%     'log'
%     };

joints = {'hip', 'knee', 'ankle'}';
% joints = {'hip'}';

%% Loop over conditions

for iJoint = 1:length(joints)
    joint = joints{iJoint};

    % local options
    options = globalOptions;
    options.formula = 'Y ~ Condition*Side + (Condition+Side|Subject)';
    options.title = sprintf('%s', capitalize(joint));
    options.outDir = sprintf('%s/%s', resultsDir, joint);
    options.constraint = sprintf('Joint == %s', joint);

    % run statistics
    kbstat(options);
end
